@@ -1,18 +1,29 @@
 # encoding: utf-8
-try:
-    from django.contrib.auth import get_user_model
-except ImportError:  # django < 1.5
-    from django.contrib.auth.models import User
-else:
-    User = get_user_model()
 
 from south.db import db
 from django.db import models
 from south.v2 import SchemaMigration
+from pybb.compat import get_image_field_full_name, get_user_model_path, get_user_frozen_models
+from pybb.defaults import PYBB_INITIAL_CUSTOM_USER_MIGRATION
+
+
+AUTH_USER = get_user_model_path()
+AUTH_USER_COLUMN = AUTH_USER.split('.')[-1].lower()
+
+
+if PYBB_INITIAL_CUSTOM_USER_MIGRATION:
+    # Runs custom user migrations (if there are) before
+    # running pybb migrations
+    DEPENDS_ON_CUSTOM_USER_MIGRATION = (
+        (AUTH_USER.split('.')[0], PYBB_INITIAL_CUSTOM_USER_MIGRATION),
+    )
+else:
+    DEPENDS_ON_CUSTOM_USER_MIGRATION = ()
 
 
 class Migration(SchemaMigration):
-    
+    depends_on = DEPENDS_ON_CUSTOM_USER_MIGRATION
+
     def forwards(self, orm):
 
         # Adding model 'Post'
@@ -22,10 +33,10 @@ class Migration(SchemaMigration):
             ('body_html', self.gf('django.db.models.fields.TextField')()),
             ('body_text', self.gf('django.db.models.fields.TextField')()),
             ('topic', self.gf('django.db.models.fields.related.ForeignKey')(related_name='posts', to=orm['pybb.Topic'])),
-            ('user', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'posts', to=orm["%s.%s" % (User._meta.app_label, User._meta.object_name)])),
+            ('user', self.gf('django.db.models.fields.related.ForeignKey')(related_name='posts', to=orm[AUTH_USER])),
             ('created', self.gf('django.db.models.fields.DateTimeField')(db_index=True, blank=True)),
             ('updated', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
-            ('user_ip', self.gf('django.db.models.fields.IPAddressField')(default=u'0.0.0.0', max_length=15, blank=True)),
+            ('user_ip', self.gf('django.db.models.fields.IPAddressField')(default='0.0.0.0', max_length=15, blank=True)),
             ('markup', self.gf('django.db.models.fields.CharField')(max_length=15)),
         ))
         db.send_create_signal('pybb', ['Post'])
@@ -41,7 +52,7 @@ class Migration(SchemaMigration):
         # Adding model 'Forum'
         db.create_table('pybb_forum', (
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
-            ('category', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'forums', to=orm['pybb.Category'])),
+            ('category', self.gf('django.db.models.fields.related.ForeignKey')(related_name='forums', to=orm['pybb.Category'])),
             ('name', self.gf('django.db.models.fields.CharField')(max_length=80)),
             ('position', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
             ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
@@ -57,11 +68,11 @@ class Migration(SchemaMigration):
             ('signature', self.gf('django.db.models.fields.TextField')(max_length=1024, blank=True)),
             ('signature_html', self.gf('django.db.models.fields.TextField')(max_length=1054, blank=True)),
             ('time_zone', self.gf('django.db.models.fields.FloatField')(default=3.0)),
-            ('language', self.gf('django.db.models.fields.CharField')(default=u'en-us', max_length=10, blank=True)),
+            ('language', self.gf('django.db.models.fields.CharField')(default='en-us', max_length=10, blank=True)),
             ('show_signatures', self.gf('django.db.models.fields.BooleanField')(default=True)),
             ('post_count', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
-            ('avatar', self.gf('sorl.thumbnail.fields.ImageField')(max_length=100, null=True, blank=True)),
-            ('user', self.gf('annoying.fields.AutoOneToOneField')(related_name=u'pybb_profile', unique=True, to=orm["%s.%s" % (User._meta.app_label, User._meta.object_name)])),
+            ('avatar', self.gf(get_image_field_full_name())(max_length=100, null=True, blank=True)),
+            ('user', self.gf('annoying.fields.AutoOneToOneField')(related_name='pybb_profile', unique=True, to=orm[AUTH_USER])),
             ('markup', self.gf('django.db.models.fields.CharField')(max_length=15)),
             ('ban_status', self.gf('django.db.models.fields.SmallIntegerField')(default=0)),
             ('ban_till', self.gf('django.db.models.fields.DateTimeField')(default=None, null=True, blank=True)),
@@ -71,7 +82,7 @@ class Migration(SchemaMigration):
         # Adding model 'Attachment'
         db.create_table('pybb_attachment', (
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
-            ('post', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'attachments', to=orm['pybb.Post'])),
+            ('post', self.gf('django.db.models.fields.related.ForeignKey')(related_name='attachments', to=orm['pybb.Post'])),
             ('size', self.gf('django.db.models.fields.IntegerField')()),
             ('hash', self.gf('django.db.models.fields.CharField')(blank=True, default='', max_length=40, db_index=True)),
             ('content_type', self.gf('django.db.models.fields.CharField')(max_length=255)),
@@ -83,7 +94,7 @@ class Migration(SchemaMigration):
         # Adding model 'ReadTracking'
         db.create_table('pybb_readtracking', (
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
-            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm["%s.%s" % (User._meta.app_label, User._meta.object_name)])),
+            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm[AUTH_USER])),
             ('topics', self.gf('django.db.models.fields.TextField')(null=True)),
             ('last_read', self.gf('django.db.models.fields.DateTimeField')(null=True)),
         ))
@@ -96,7 +107,7 @@ class Migration(SchemaMigration):
             ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
             ('created', self.gf('django.db.models.fields.DateTimeField')(null=True)),
             ('updated', self.gf('django.db.models.fields.DateTimeField')(null=True)),
-            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm["%s.%s" % (User._meta.app_label, User._meta.object_name)])),
+            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm[AUTH_USER])),
             ('views', self.gf('django.db.models.fields.IntegerField')(default=0, blank=True)),
             ('sticky', self.gf('django.db.models.fields.BooleanField')(default=False)),
             ('closed', self.gf('django.db.models.fields.BooleanField')(default=False)),
@@ -108,17 +119,17 @@ class Migration(SchemaMigration):
         db.create_table('pybb_topic_subscribers', (
             ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
             ('topic', models.ForeignKey(orm['pybb.topic'], null=False)),
-            ('user', models.ForeignKey(orm['auth.user'], null=False))
+            (AUTH_USER_COLUMN, models.ForeignKey(orm[AUTH_USER], null=False))
         ))
-        db.create_unique('pybb_topic_subscribers', ['topic_id', 'user_id'])
+        db.create_unique('pybb_topic_subscribers', ['topic_id', '%s_id' % AUTH_USER_COLUMN])
 
         # Adding M2M table for field moderators on 'Forum'
         db.create_table('pybb_forum_moderators', (
             ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
             ('forum', models.ForeignKey(orm['pybb.forum'], null=False)),
-            ('user', models.ForeignKey(orm['auth.user'], null=False))
+            (AUTH_USER_COLUMN, models.ForeignKey(orm[AUTH_USER], null=False))
         ))
-        db.create_unique('pybb_forum_moderators', ['forum_id', 'user_id'])
+        db.create_unique('pybb_forum_moderators', ['forum_id', '%s_id' % AUTH_USER_COLUMN])
     
     
     def backwards(self, orm):
@@ -165,21 +176,6 @@ class Migration(SchemaMigration):
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
         },
-        'auth.user': {
-            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
-            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
-            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
-            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'blank': 'True'}),
-            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
-            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
-            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
-            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
-            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
-            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
-            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'blank': 'True'}),
-            'username': ('django.db.models.fields.CharField', [], {'max_length': '30', 'unique': 'True'})
-        },
         'contenttypes.contenttype': {
             'Meta': {'unique_together': "(('app_label', 'model'),)", 'db_table': "'django_content_type'"},
             'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
@@ -205,7 +201,7 @@ class Migration(SchemaMigration):
             'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'forums'", 'to': "orm['pybb.Category']"}),
             'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'moderators': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['%s.%s']"% (User._meta.app_label, User._meta.object_name), 'null': 'True', 'blank': 'True'}),
+            'moderators': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['%s']"% AUTH_USER, 'null': 'True', 'blank': 'True'}),
             'name': ('django.db.models.fields.CharField', [], {'max_length': '80'}),
             'position': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
             'post_count': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
@@ -221,7 +217,7 @@ class Migration(SchemaMigration):
             'markup': ('django.db.models.fields.CharField', [], {'default': "'bbcode'", 'max_length': '15'}),
             'topic': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'posts'", 'to': "orm['pybb.Topic']"}),
             'updated': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
-            'user': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'posts'", 'to': "orm['%s.%s']"% (User._meta.app_label, User._meta.object_name)}),
+            'user': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'posts'", 'to': "orm['%s']"% AUTH_USER}),
             'user_ip': ('django.db.models.fields.IPAddressField', [], {'default': "'0.0.0.0'", 'max_length': '15', 'blank': 'True'})
         },
         'pybb.profile': {
@@ -236,13 +232,13 @@ class Migration(SchemaMigration):
             'signature': ('django.db.models.fields.TextField', [], {'max_length': '1024', 'blank': 'True'}),
             'signature_html': ('django.db.models.fields.TextField', [], {'max_length': '1054', 'blank': 'True'}),
             'time_zone': ('django.db.models.fields.FloatField', [], {'default': '3.0'}),
-            'user': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['%s.%s']"% (User._meta.app_label, User._meta.object_name), 'related_name': "'pybb_profile'", 'unique': 'True'})
+            'user': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['%s']"% AUTH_USER, 'related_name': "'pybb_profile'", 'unique': 'True'})
         },
         'pybb.readtracking': {
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'last_read': ('django.db.models.fields.DateTimeField', [], {'null': 'True'}),
             'topics': ('django.db.models.fields.TextField', [], {'null': 'True'}),
-            'user': ('django.db.models.fields.related.OneToOneField', [], {'unique': 'True', 'to': "orm['%s.%s']"% (User._meta.app_label, User._meta.object_name)})
+            'user': ('django.db.models.fields.related.OneToOneField', [], {'unique': 'True', 'to': "orm['%s']"% AUTH_USER})
         },
         'pybb.topic': {
             'closed': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
@@ -252,11 +248,12 @@ class Migration(SchemaMigration):
             'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
             'post_count': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
             'sticky': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
-            'subscribers': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['%s.%s']"% (User._meta.app_label, User._meta.object_name), 'blank': 'True'}),
+            'subscribers': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['%s']"% AUTH_USER, 'blank': 'True'}),
             'updated': ('django.db.models.fields.DateTimeField', [], {'blank': 'True', 'null': 'True'}),
-            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['%s.%s']"% (User._meta.app_label, User._meta.object_name)}),
+            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['%s']"% AUTH_USER}),
             'views': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'})
         }
     }
-    
+    models.update(get_user_frozen_models(AUTH_USER))
+
     complete_apps = ['pybb']
